﻿using Microsoft.AspNetCore.Components;
using Blazorise.DataGrid;
using Blazor.ViewClasses;
using Blazor.Modals;
using Blazored.LocalStorage;
using Blazored.Modal.Services;
using Blazor.Services;
using Blazored.Modal;

namespace Blazor.Pages.Admins;

public partial class Administrators
{
    public List<Administrator> administrators = new();

    private int totalItem;
    [CascadingParameter]
    public required IModalService Modal { get; set; }

    [Inject]
    public required IDataService DataService { get; set; }

    [Inject]
    public required IWebHostEnvironment WebHostEnvironment { get; set; }

    [Inject]
    public required ILocalStorageService LocalStorage { get; set; }

    [Inject]
    public required HttpClient Http { get; set; }

    [Inject]
    public required NavigationManager NavigationManager { get; set; }

    private async Task OnReadData(DataGridReadDataEventArgs<Administrator> e)
    {
        if (e.CancellationToken.IsCancellationRequested)
        {
            return;
        }

        var response = Http.GetFromJsonAsync<Administrator[]>(API.API_URL+"administrators/"+API.TOKEN).Result;

        if (!e.CancellationToken.IsCancellationRequested && response != null)
        {
            administrators = new List<Administrator>(response); // an actual data for the current page
            totalItem = administrators.Count;
            var currentData = await LocalStorage.GetItemAsync<Administrator[]>("data");
            if (currentData == null || currentData.Length != administrators.Count)
            {
                var originalData = Http.GetFromJsonAsync<Administrator[]>(API.API_URL + "administrators/" + API.TOKEN).Result;
                await LocalStorage.SetItemAsync("data", originalData);
            }
        }
    }

    private async void OnDelete(int id)
    {
        var parameters = new ModalParameters();
        parameters.Add(nameof(Administrator.Id), id);

        var modal = Modal.Show<DeleteConfirmation>("Delete Confirmation", parameters);
        var result = await modal.Result;

        if (result.Cancelled)
        {
            return;
        }

        string apiUri = API.API_URL +"delete/administrator/" + id + "/" + API.TOKEN;

        using (var httpClient = new HttpClient())
        {
            var response = await httpClient.DeleteAsync(apiUri);

            if (response.IsSuccessStatusCode)
            {
                var responseBody = await response.Content.ReadAsStringAsync();
            }
            else
            {
                var errorResponse = await response.Content.ReadAsStringAsync();
            }
        }

        NavigationManager.NavigateTo("administrators", true);
    }
}
