﻿using Microsoft.AspNetCore.Components;
using Blazor.Models;
using Blazor.Services;
using Blazor.Pages.Admins;
using Blazor.ViewClasses;
using static System.Net.WebRequestMethods;

namespace Blazor.Pages.Questions
{
    public partial class AddQuestion
    {
        private QuestionModel questionModel = new();

        public List<Chapter> chapters = new();

        private List<AnswerModel> answerModels = new();
        
        public List<Checkbox> checkboxs = new();

        [Inject]
        public required IDataService DataService { get; set; }

        [Inject]
        public required NavigationManager NavigationManager { get; set; }

        [Inject]
        public required HttpClient Http { get; set; }

        [Inject]
        public required ILogger<AddAdministrator> Logger { get; set; }
        public class Checkbox
        {
            public int Id { get; set; }
            public bool IsCorrect { get; set; }

            public Checkbox(int id) { Id = id; IsCorrect = false; }
        }

        protected override async Task OnInitializedAsync()
        {
            var response = Http.GetFromJsonAsync<Chapter[]>(API.API_URL + "chapters/" + API.TOKEN).Result;
            if (response == null) chapters = new List<Chapter>();
            else chapters = new List<Chapter>(response);

            answerModels = new();
            checkboxs = new();
            for(int i = 0; i < 4; i++) 
            {
                answerModels.Add(new AnswerModel(i));
                checkboxs.Add(new Checkbox(i));
            }
        }
        private async Task HandleValidSubmit()
        {
            if (questionModel != null)
            {
                await DataService.Add(questionModel);

            var formData = new List<KeyValuePair<string, string>>();
            formData.Add(new KeyValuePair<string, string>("content", questionModel.Content));
            formData.Add(new KeyValuePair<string, string>("idchapter", questionModel.IdChapter.ToString()));
            foreach (var answerModel in answerModels)
            {
                var answercontent = $"answerContent{answerModel.Id + 1}";
                formData.Add(new KeyValuePair<string, string>(answercontent, answerModel.Content));
            }
            foreach (var checkbox in checkboxs)
            {
                if (checkbox.IsCorrect != false)
                {
                    var idgood = checkbox.Id + 1;
                    formData.Add(new KeyValuePair<string, string>("idanswergood", idgood.ToString()));
                }
            }
             
            var formContent = new FormUrlEncodedContent(formData);

                string apiUri = API.API_URL + "add/question/" + API.TOKEN;

                using (var httpClient = new HttpClient())
                {
                    var response = await httpClient.PostAsync(apiUri, formContent);

                    if (response.IsSuccessStatusCode)
                    {
                        var responseBody = await response.Content.ReadAsStringAsync();
                    }
                    else
                    {
                        var errorResponse = await response.Content.ReadAsStringAsync();
                    }
                }

                NavigationManager.NavigateTo("questions");
            }
        }
    }
}
